# Nineties

Ease the reading of relics from the Nineties.

[License: MIT](https://git.sr.ht/~sthagen/nineties/tree/default/item/LICENSE)

[![version](https://img.shields.io/pypi/v/nineties.svg?style=flat)](https://pypi.python.org/pypi/nineties/)
[![downloads](https://img.shields.io/pypi/dm/nineties.svg?style=flat)](https://pypi.python.org/pypi/nineties/)
[![wheel](https://img.shields.io/pypi/wheel/nineties.svg?style=flat)](https://pypi.python.org/pypi/nineties/)
[![supported-versions](https://img.shields.io/pypi/pyversions/nineties.svg?style=flat)](https://pypi.python.org/pypi/nineties/)
[![supported-implementations](https://img.shields.io/pypi/implementation/nineties.svg?style=flat)](https://pypi.python.org/pypi/nineties/)

## Documentation

User and developer [documentation of nineties](https://codes.dilettant.life/docs/nineties).

## Bug Tracker

Feature requests and bug reports are bested entered in the [todos of nineties](https://todo.sr.ht/~sthagen/nineties).

## Primary Source repository

The primary source repository of [nineties is at sourcehut](https://git.sr.ht/~sthagen/nineties)
a collection of tools useful for software development.

## Random Notes
### What is in

A small, maybe growing collection of parsers and filters
to ease dealing with specific information structures that
drop off of REST backends ;-)

### What is out (for now)

Everything else (for now)
## Status

Experimental

**Note**: The default branch is `default`.
